@@ -50,33 +50,39 @@ impl Display for FromFloatConversionError {
     }
 }
 
-pub enum ParsingError {
+pub enum FromStringConversionError {
     StartsWithSeparator,
     ConsecutiveSeparators,
     InvalidDigit(char, u8),
     EndsWithSeparator,
 }
 
-impl ParsingError {
+impl FromStringConversionError {
     fn description(&self) -> String {
         match self {
-            ParsingError::StartsWithSeparator => String::from("Should not start with separator."),
-            ParsingError::InvalidDigit(character, base) => {
+            FromStringConversionError::StartsWithSeparator => {
+                String::from("Should not start with separator.")
+            }
+            FromStringConversionError::InvalidDigit(character, base) => {
                 format!("Invalid digit in base {}: {}.", base, character)
             }
-            ParsingError::ConsecutiveSeparators => String::from("Consecutive separators found."),
-            ParsingError::EndsWithSeparator => String::from("Should not end with separator."),
+            FromStringConversionError::ConsecutiveSeparators => {
+                String::from("Consecutive separators found.")
+            }
+            FromStringConversionError::EndsWithSeparator => {
+                String::from("Should not end with separator.")
+            }
         }
     }
 }
 
-impl Debug for ParsingError {
+impl Debug for FromStringConversionError {
     fn fmt(&self, formatter: &mut Formatter<'_>) -> std::fmt::Result {
         formatter.write_str(&self.description())
     }
 }
 
-impl Display for ParsingError {
+impl Display for FromStringConversionError {
     fn fmt(&self, formatter: &mut Formatter<'_>) -> std::fmt::Result {
         Display::fmt(&self.description(), formatter)
     }
@@ -152,7 +158,7 @@ impl<Digit: FromStrDigit, const SEPARATOR: char, const SHIFT: usize>
         37,
     ];
 
-    fn new(string: &str, mut base: u8) -> Result<Self, ParsingError> {
+    fn new(string: &str, mut base: u8) -> Result<Self, FromStringConversionError> {
         debug_assert!(is_valid_shift::<Digit, SHIFT>());
         debug_assert!(Self::ASCII_CODES_DIGIT_VALUES[SEPARATOR as usize] >= MAX_REPRESENTABLE_BASE);
         let mut characters = string.trim().chars().peekable();
@@ -185,9 +191,12 @@ impl<Digit: FromStrDigit, const SEPARATOR: char, const SHIFT: usize>
     }
 
     #[inline]
-    fn parse_digits(mut characters: Peekable<Chars>, base: u8) -> Result<Vec<u8>, ParsingError> {
+    fn parse_digits(
+        mut characters: Peekable<Chars>,
+        base: u8,
+    ) -> Result<Vec<u8>, FromStringConversionError> {
         if characters.peek() == Some(&SEPARATOR) {
-            return Err(ParsingError::StartsWithSeparator);
+            return Err(FromStringConversionError::StartsWithSeparator);
         }
         let mut result: Vec<u8> = Vec::new();
         let mut prev: char = SEPARATOR;
@@ -195,16 +204,16 @@ impl<Digit: FromStrDigit, const SEPARATOR: char, const SHIFT: usize>
             if character != SEPARATOR {
                 let digit = Self::ASCII_CODES_DIGIT_VALUES[character as usize];
                 if digit >= base {
-                    return Err(ParsingError::InvalidDigit(character, base));
+                    return Err(FromStringConversionError::InvalidDigit(character, base));
                 }
                 result.push(digit);
             } else if prev == SEPARATOR {
-                return Err(ParsingError::ConsecutiveSeparators);
+                return Err(FromStringConversionError::ConsecutiveSeparators);
             }
             prev = character;
         }
         if prev == SEPARATOR {
-            return Err(ParsingError::EndsWithSeparator);
+            return Err(FromStringConversionError::EndsWithSeparator);
         }
         result.reverse();
         Ok(result)
@@ -256,7 +265,7 @@ impl<Digit, const SEPARATOR: char, const SHIFT: usize> BigInt<Digit, SEPARATOR,
     }
 }
 
-impl<Digit: DisplayDigit, const SEPARATOR: char, const SHIFT: usize>
+impl<Digit: DisplayableDigit, const SEPARATOR: char, const SHIFT: usize>
     BigInt<Digit, SEPARATOR, SHIFT>
 {
     const DIGIT_VALUES_ASCII_CODES: [char; MAX_REPRESENTABLE_BASE as usize] = [
@@ -701,7 +710,7 @@ impl<Digit: EuclidDivisibleDigit, const SEPARATOR: char, const SHIFT: usize> Che
     }
 }
 
-impl<Digit: DisplayDigit, const SEPARATOR: char, const SHIFT: usize> Display
+impl<Digit: DisplayableDigit, const SEPARATOR: char, const SHIFT: usize> Display
     for BigInt<Digit, SEPARATOR, SHIFT>
 {
     fn fmt(&self, formatter: &mut Formatter) -> std::fmt::Result {
@@ -805,7 +814,7 @@ impl<Digit: EuclidDivisibleDigit, const SEPARATOR: char, const SHIFT: usize> Div
     }
 }
 
-impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT: usize>
+impl<Digit: DigitConvertibleFromFloat, const SEPARATOR: char, const SHIFT: usize>
     FloatToInt<BigInt<Digit, SEPARATOR, SHIFT>> for f32
 {
     unsafe fn to_int_unchecked(self) -> BigInt<Digit, SEPARATOR, SHIFT> {
@@ -813,7 +822,7 @@ impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT:
     }
 }
 
-impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT: usize>
+impl<Digit: DigitConvertibleFromFloat, const SEPARATOR: char, const SHIFT: usize>
     FloatToInt<BigInt<Digit, SEPARATOR, SHIFT>> for f64
 {
     unsafe fn to_int_unchecked(self) -> BigInt<Digit, SEPARATOR, SHIFT> {
@@ -834,11 +843,11 @@ where
             Self::zero()
         } else if size_of::<SourceDigit>() < size_of::<TargetDigit>()
             || (size_of::<SourceDigit>() == size_of::<TargetDigit>()
-                && utils::are_same::<SourceDigit, OppositionOf<SourceDigit>>()
-                && !utils::are_same::<TargetDigit, OppositionOf<TargetDigit>>())
+                && utils::is_signed::<SourceDigit>()
+                && utils::is_unsigned::<TargetDigit>())
         {
             let mut sign = Sign::one();
-            let mut value = if utils::are_same::<SourceDigit, OppositionOf<SourceDigit>>() {
+            let mut value = if utils::is_signed::<SourceDigit>() {
                 let value =
                     unsafe { OppositionOf::<SourceDigit>::try_from(value).unwrap_unchecked() };
                 if value.is_negative() {
@@ -865,7 +874,7 @@ where
             Self { sign, digits }
         } else {
             let mut sign = Sign::one();
-            let mut value = if utils::are_same::<SourceDigit, OppositionOf<SourceDigit>>() {
+            let mut value = if utils::is_signed::<SourceDigit>() {
                 let value =
                     unsafe { OppositionOf::<SourceDigit>::try_from(value).unwrap_unchecked() };
                 if value.is_negative() {
@@ -892,7 +901,7 @@ where
 impl<Digit: FromStrDigit, const SEPARATOR: char, const SHIFT: usize> FromStrRadix
     for BigInt<Digit, SEPARATOR, SHIFT>
 {
-    type Error = ParsingError;
+    type Error = FromStringConversionError;
 
     fn from_str_radix(string: &str, radix: u32) -> Result<Self, Self::Error> {
         if (radix != 0 && radix < 2) || radix > (MAX_REPRESENTABLE_BASE as u32) {
@@ -928,8 +937,7 @@ impl<Digit: GcdDigit, const SEPARATOR: char, const SHIFT: usize> Gcd
                     digits: largest_digits,
                 };
             }
-            let highest_digit_bit_length =
-                utils::bit_length(largest_digits[largest_digits.len() - 1]);
+            let highest_digit_bit_length = largest_digits[largest_digits.len() - 1].bit_length();
             let mut largest_leading_bits = (OppositionOf::<DoublePrecisionOf<Digit>>::from(
                 largest_digits[largest_digits_count - 1],
             ) << (2 * SHIFT - highest_digit_bit_length))
@@ -1050,10 +1058,11 @@ impl<Digit: GcdDigit, const SEPARATOR: char, const SHIFT: usize> Gcd
             largest_digits = next_largest_digits;
             smallest_digits = next_smallest_digits;
         }
-        Self::from(utils::gcd::<DoublePrecisionOf<Digit>>(
-            reduce_digits::<Digit, DoublePrecisionOf<Digit>, SHIFT>(&largest_digits),
-            reduce_digits::<Digit, DoublePrecisionOf<Digit>, SHIFT>(&smallest_digits),
-        ))
+        Self::from(
+            reduce_digits::<Digit, DoublePrecisionOf<Digit>, SHIFT>(&largest_digits).gcd(
+                reduce_digits::<Digit, DoublePrecisionOf<Digit>, SHIFT>(&smallest_digits),
+            ),
+        )
     }
 }
 
@@ -1495,7 +1504,7 @@ impl<Digit: AdditiveDigit, const SEPARATOR: char, const SHIFT: usize> SubAssign
     }
 }
 
-impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT: usize> TryFrom<f64>
+impl<Digit: DigitConvertibleFromFloat, const SEPARATOR: char, const SHIFT: usize> TryFrom<f64>
     for BigInt<Digit, SEPARATOR, SHIFT>
 {
     type Error = FromFloatConversionError;
@@ -1522,7 +1531,7 @@ impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT:
     }
 }
 
-impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT: usize> TryFrom<f32>
+impl<Digit: DigitConvertibleFromFloat, const SEPARATOR: char, const SHIFT: usize> TryFrom<f32>
     for BigInt<Digit, SEPARATOR, SHIFT>
 {
     type Error = FromFloatConversionError;
@@ -1535,7 +1544,7 @@ impl<Digit: DigitConvertibleFromFloat<f64>, const SEPARATOR: char, const SHIFT:
 impl<Digit: FromStrDigit, const SEPARATOR: char, const SHIFT: usize> TryFrom<&str>
     for BigInt<Digit, SEPARATOR, SHIFT>
 {
-    type Error = ParsingError;
+    type Error = FromStringConversionError;
 
     fn try_from(string: &str) -> Result<Self, Self::Error> {
         Self::new(string, 0)
@@ -1605,5 +1614,5 @@ impl<Digit: ZeroableDigit, const SEPARATOR: char, const SHIFT: usize> Zeroable
 }
 
 const fn is_valid_shift<Digit: Oppose, const SHIFT: usize>() -> bool {
-    SHIFT < 8 * size_of::<Digit>() - (utils::are_same::<Digit, OppositionOf<Digit>>() as usize)
+    SHIFT < 8 * size_of::<Digit>() - (utils::is_signed::<Digit>() as usize)
 }
