@@ -177,12 +177,10 @@ impl PyFraction {
                     } else {
                         _Fraction::try_from(value.extract::<f64>()?).map_err(
                             |reason| match reason {
-                                fraction::FromFloatConversionError::Infinity => {
-                                    PyOverflowError::new_err(reason.to_string())
-                                }
                                 fraction::FromFloatConversionError::NaN => {
                                     PyValueError::new_err(reason.to_string())
                                 }
+                                _ => PyOverflowError::new_err(reason.to_string()),
                             },
                         )?
                     }
@@ -213,9 +211,9 @@ impl PyFraction {
     fn __setstate__(&mut self, py: Python, state: PyObject) -> PyResult<()> {
         state.extract::<(PyObject, PyObject)>(py).and_then(
             |(numerator_state, denominator_state)| {
-                let mut numerator = PyInt { 0: _BigInt::zero() };
+                let mut numerator = PyInt(_BigInt::zero());
                 numerator.__setstate__(py, numerator_state)?;
-                let mut denominator = PyInt { 0: _BigInt::zero() };
+                let mut denominator = PyInt(_BigInt::zero());
                 denominator.__setstate__(py, denominator_state)?;
                 self.0 = unsafe { _Fraction::new(numerator.0, denominator.0).unwrap_unchecked() };
                 Ok(())
