@@ -1,5 +1,7 @@
 import fractions
-from typing import Tuple
+import pickle
+from typing import (Tuple,
+                    TypeVar)
 
 from rithm import (Fraction,
                    Int)
@@ -20,16 +22,23 @@ def is_equivalent_to_builtin_fraction(value: Fraction,
 
 
 def is_equivalent_to_builtin_int(value: Int, builtin: int) -> bool:
-    return str(value) == str(builtin)
+    return int(value) == builtin
 
 
-def to_int_with_builtin_int(decimal_string: str) -> Tuple[Int, int]:
+_Pickleable = TypeVar('_Pickleable')
+
+
+def pickle_round_trip(value: _Pickleable) -> _Pickleable:
+    return pickle.loads(pickle.dumps(value))
+
+
+def to_int_with_builtin(decimal_string: str) -> IntWithBuiltin:
     return Int(decimal_string), int(decimal_string)
 
 
-def to_fraction_with_builtin_fraction(numerators_pair: Tuple[Int, int],
-                                      denominators_pair: Tuple[Int, int]
-                                      ) -> Tuple[Fraction, fractions.Fraction]:
+def to_fraction_with_builtin(numerators_pair: IntWithBuiltin,
+                             denominators_pair: IntWithBuiltin
+                             ) -> FractionWithBuiltin:
     numerator, builtin_numerator = numerators_pair
     denominator, builtin_denominator = denominators_pair
     return (Fraction(numerator, denominator),
